@@ -395,8 +395,7 @@ class BaseCursor(Generic[ConnectionType, Row]):
         query = self._convert_query(statement)
 
         self._execute_send(query, binary=False)
-        results = yield from execute(self._pgconn)
-        if len(results) != 1:
+        if len(results := (yield from execute(self._pgconn))) != 1:
             raise e.ProgrammingError("COPY cannot be mixed with other operations")
 
         self._check_copy_result(results[0])
@@ -473,8 +472,7 @@ class BaseCursor(Generic[ConnectionType, Row]):
         """
         Raise an appropriate error message for an unexpected database result
         """
-        status = result.status
-        if status == FATAL_ERROR:
+        if (status := result.status) == FATAL_ERROR:
             raise e.error_from_result(result, encoding=self._encoding)
         elif status == PIPELINE_ABORTED:
             raise e.PipelineAborted("pipeline aborted")
@@ -518,19 +516,17 @@ class BaseCursor(Generic[ConnectionType, Row]):
             # Received from execute()
             self._results[:] = results
             self._select_current_result(0)
-
+        # Received from executemany()
+        elif self._execmany_returning:
+            first_batch = not self._results
+            self._results.extend(results)
+            if first_batch:
+                self._select_current_result(0)
         else:
-            # Received from executemany()
-            if self._execmany_returning:
-                first_batch = not self._results
-                self._results.extend(results)
-                if first_batch:
-                    self._select_current_result(0)
-            else:
-                # In non-returning case, set rowcount to the cumulated number of
-                # rows of executed queries.
-                for res in results:
-                    self._rowcount += res.command_tuples or 0
+            # In non-returning case, set rowcount to the cumulated number of
+            # rows of executed queries.
+            for res in results:
+                self._rowcount += res.command_tuples or 0
 
     def _send_prepare(self, name: bytes, query: PostgresQuery) -> None:
         if self._conn._pipeline:
@@ -569,22 +565,31 @@ class BaseCursor(Generic[ConnectionType, Row]):
                 name, pgq.params, param_formats=pgq.formats, result_format=fmt
             )
 
-    def _check_result_for_fetch(self) -> None:
+    def _check_result_for_fetch(self) -> PGresult:
         if self.closed:
             raise e.InterfaceError("the cursor is closed")
-        res = self.pgresult
-        if not res:
+
+        if not (res := self.pgresult):
             raise e.ProgrammingError("no result available")
 
-        status = res.status
-        if status == TUPLES_OK:
-            return
+        if (status := res.status) == TUPLES_OK:
+            return res
         elif status == FATAL_ERROR:
             raise e.error_from_result(res, encoding=self._encoding)
         elif status == PIPELINE_ABORTED:
             raise e.PipelineAborted("pipeline aborted")
         else:
-            raise e.ProgrammingError("the last operation didn't produce a result")
+            if res.command_status:
+                detail = f" (command status: {res.command_status.decode()})"
+            else:
+                try:
+                    status_name = pq.ExecStatus(status).name
+                except ValueError:
+                    status_name = f"{status} - unknown"
+                detail = f" (result status: {status_name})"
+            raise e.ProgrammingError(
+                f"the last operation didn't produce records{detail}"
+            )
 
     def _check_copy_result(self, result: PGresult) -> None:
         """
@@ -602,15 +607,14 @@ class BaseCursor(Generic[ConnectionType, Row]):
             )
 
     def _scroll(self, value: int, mode: str) -> None:
-        self._check_result_for_fetch()
-        assert self.pgresult
+        res = self._check_result_for_fetch()
         if mode == "relative":
             newpos = self._pos + value
         elif mode == "absolute":
             newpos = value
         else:
             raise ValueError(f"bad mode: {mode}. It should be 'relative' or 'absolute'")
-        if not 0 <= newpos < self.pgresult.ntuples:
+        if not 0 <= newpos < res.ntuples:
             raise IndexError("position out of bound")
         self._pos = newpos
 
