@@ -38,12 +38,10 @@ def check_crdb_version(got, mark):
     pred = VersionCheck.parse(spec)
     pred.whose = "CockroachDB"
 
-    msg = pred.get_skip_message(got)
-    if not msg:
+    if not (msg := pred.get_skip_message(got)):
         return None
 
-    reason = crdb_skip_message(reason)
-    if reason:
+    if reason := crdb_skip_message(reason):
         msg = f"{msg}: {reason}"
 
     return msg
@@ -81,6 +79,10 @@ def crdb_scs_off(*args):
     return skip_crdb(*args, reason="standard_conforming_strings=off")
 
 
+def crdb_anydb(*args):
+    return skip_crdb(*args, reason="can connect to any db name")
+
+
 # mapping from reason description to ticket number
 _crdb_reasons = {
     "2-phase commit": 22329,
