@@ -16,6 +16,9 @@ import pytest
 import psycopg
 import psycopg.generators
 from psycopg import pq
+from psycopg.conninfo import make_conninfo
+
+from ..fix_crdb import crdb_anydb
 
 if TYPE_CHECKING:
     from psycopg.pq.abc import PGcancelConn, PGconn
@@ -30,8 +33,8 @@ def wait(
     poll = getattr(conn, poll_method)
     while True:
         assert conn.status != pq.ConnStatus.BAD, conn.error_message
-        rv = poll()
-        if rv == return_on:
+
+        if (rv := poll()) == return_on:
             return
         elif rv == pq.PollingStatus.READING:
             select([conn.socket], [], [], timeout)
@@ -49,8 +52,9 @@ def test_connectdb(dsn):
     assert conn.status == pq.ConnStatus.OK, conn.error_message
 
 
-def test_connectdb_error():
-    conn = pq.PGconn.connect(b"dbname=psycopg_test_not_for_real")
+@crdb_anydb
+def test_connectdb_error(dsn):
+    conn = pq.PGconn.connect(make_conninfo(dsn, dbname="nosuchdb").encode())
     assert conn.status == pq.ConnStatus.BAD
 
 
@@ -179,7 +183,7 @@ def test_ping(dsn):
     rv = pq.PGconn.ping(dsn.encode())
     assert rv == pq.Ping.OK
 
-    rv = pq.PGconn.ping(b"port=9999")
+    rv = pq.PGconn.ping(make_conninfo(dsn, port=9999, connect_timeout=3).encode())
     assert rv == pq.Ping.NO_RESPONSE
 
 
@@ -362,17 +366,27 @@ def test_used_password(pgconn, dsn, monkeypatch):
     # so it may be that has_password is false but still a password was
     # requested by the server and passed by libpq.
     info = pq.Conninfo.parse(dsn.encode())
-    has_password = (
-        "PGPASSWORD" in os.environ
-        or [i for i in info if i.keyword == b"password"][0].val is not None
-    )
-    if has_password:
+
+    if "PGPASSWORD" in os.environ:
+        assert pgconn.used_password
+    if [i for i in info if i.keyword == b"password"][0].val is not None:
         assert pgconn.used_password
 
     pgconn.finish()
     pgconn.used_password
 
 
+@pytest.mark.libpq(">= 16")
+def test_used_gssapi(pgconn):
+    assert isinstance(pgconn.used_gssapi, bool)
+
+
+@pytest.mark.libpq("< 16")
+def test_used_gssapi_not_suppored(pgconn):
+    with pytest.raises(psycopg.NotSupportedError):
+        pgconn.used_gssapi
+
+
 def test_ssl_in_use(pgconn):
     assert isinstance(pgconn.ssl_in_use, bool)
 
