@@ -280,7 +280,9 @@ async def test_warn_close(aconn, recwarn, gc_collect):
     await cur.execute("select generate_series(1, 10) as bar")
     del cur
     gc_collect()
-    assert ".close()" in str(recwarn.pop(ResourceWarning).message)
+    msg = str(recwarn.pop(ResourceWarning).message)
+    assert aconn.server_cursor_factory.__name__ in msg
+    assert ".close()" in msg
 
 
 async def test_execute_reuse(aconn):
@@ -388,13 +390,14 @@ async def test_row_factory(aconn):
 
     cur = aconn.cursor("foo", row_factory=my_row_factory, scrollable=True)
     await cur.execute("select generate_series(1, 3) as x")
+    assert cur.rownumber == 0
     recs = await cur.fetchall()
+    assert cur.rownumber == 3
     await cur.scroll(0, "absolute")
-    while True:
-        rec = await cur.fetchone()
-        if not rec:
-            break
+    assert cur.rownumber == 0
+    while rec := (await cur.fetchone()):
         recs.append(rec)
+    assert cur.rownumber == 3
     assert recs == [[1, -1], [1, -2], [1, -3]] * 2
 
     await cur.scroll(0, "absolute")
@@ -467,17 +470,26 @@ async def test_cant_scroll_by_default(aconn):
 async def test_scroll(aconn):
     cur = aconn.cursor("tmp", scrollable=True)
     await cur.execute("select generate_series(0,9)")
+    assert cur.rownumber == 0
     await cur.scroll(2)
+    assert cur.rownumber == 2
     assert await cur.fetchone() == (2,)
+    assert cur.rownumber == 3
     await cur.scroll(2)
+    assert cur.rownumber == 5
     assert await cur.fetchone() == (5,)
+    assert cur.rownumber == 6
     await cur.scroll(2, mode="relative")
+    assert cur.rownumber == 8
     assert await cur.fetchone() == (8,)
     await cur.scroll(9, mode="absolute")
+    assert cur.rownumber == 9
     assert await cur.fetchone() == (9,)
+    assert cur.rownumber == 10
 
     with pytest.raises(ValueError):
         await cur.scroll(9, mode="wat")
+        assert cur.rownumber == 10
     await cur.close()
 
 
@@ -550,3 +562,19 @@ async def test_stolen_cursor_close(aconn):
     await cur1.execute("declare test cursor for select generate_series(1, 6)")
     cur2 = aconn.cursor("test")
     await cur2.close()
+
+
+async def test_row_maker_returns_none(aconn):
+    query = "values (null), (0)"
+    recs = [None, 0]
+    async with aconn.cursor("test", row_factory=rows.scalar_row) as cur:
+        await cur.execute(query)
+        assert [await cur.fetchone() for _ in range(len(recs))] == recs
+        await cur.execute(query)
+        assert await cur.fetchmany(len(recs)) == recs
+        await cur.execute(query)
+        assert await cur.fetchall() == recs
+        await cur.execute(query)
+        assert await alist(cur) == recs
+        stream = cur.stream(query)
+        assert await alist(stream) == recs
