@@ -11,7 +11,7 @@ from psycopg import errors as e
 from psycopg import pq
 
 from .utils import eur
-from .fix_crdb import is_crdb
+from .fix_crdb import crdb_anydb, is_crdb
 
 
 def test_finishedpgconn(pgconn):
@@ -54,7 +54,6 @@ def test_diag_right_attr(pgconn, monkeypatch):
     checked: list[pq.DiagnosticField] = []
 
     def check_val(self, v):
-        nonlocal to_check
         assert to_check == v
         checked.append(v)
         return None
@@ -287,18 +286,20 @@ def test_unknown_sqlstate(conn):
     assert pexc.sqlstate == code
 
 
-def test_pgconn_error(conn_cls):
+@crdb_anydb
+def test_pgconn_error(conn_cls, dsn):
     with pytest.raises(psycopg.OperationalError) as excinfo:
-        conn_cls.connect("dbname=nosuchdb")
+        conn_cls.connect(dsn, dbname="nosuchdb")
 
     exc = excinfo.value
     assert exc.pgconn
     assert exc.pgconn.db == b"nosuchdb"
 
 
-def test_pgconn_error_pickle(conn_cls):
+@crdb_anydb
+def test_pgconn_error_pickle(conn_cls, dsn):
     with pytest.raises(psycopg.OperationalError) as excinfo:
-        conn_cls.connect("dbname=nosuchdb")
+        conn_cls.connect(dsn, dbname="nosuchdb")
 
     exc = pickle.loads(pickle.dumps(excinfo.value))
     assert exc.pgconn is None
